==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/operation_signature.dart <==
part of keyclic_sdk_api.api;

class OperationSignature {
  OperationSignature({
    this.signer,
    this.signedAt,
  });

  OperationSignature.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    signer = OperationSignatureSigner.fromJson(json['signer']);
    signedAt =
        json['signedAt'] == null ? null : DateTime.parse(json['signedAt']);
    if (signedAt is DateTime && signedAt.isUtc == false) {
      signedAt = DateTime.parse('${signedAt.toIso8601String()}Z');
    }
  }

  OperationSignatureSigner signer;

  DateTime signedAt;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is OperationSignature &&
        runtimeType == other.runtimeType &&
        signer == other.signer &&
        signedAt == other.signedAt;
  }

  @override
  int get hashCode => 0 ^ signer.hashCode ^ signedAt.hashCode;

  Map<String, dynamic> toJson() {
    return {
      'signer': signer,
      'signedAt': signedAt == null ? '' : signedAt.toUtc().toIso8601String(),
    };
  }

  @override
  String toString() {
    return 'OperationSignature[signer=$signer, signedAt=$signedAt, ]';
  }

  static List<OperationSignature> listFromJson(List<dynamic> json) {
    return json == null
        ? List<OperationSignature>()
        : json.map((value) => OperationSignature.fromJson(value)).toList();
  }

  static Map<String, OperationSignature> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationSignature>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationSignature.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/operation_signature.dart <==
part of keyclic_sdk_api.api;

class OperationSignature {
  OperationSignature({
    this.signedAt,
    this.signer,
  });

  OperationSignature.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    signedAt =
        json['signedAt'] == null ? null : DateTime.parse(json['signedAt']);
    if (signedAt is DateTime && signedAt.isUtc == false) {
      signedAt = DateTime.parse('${signedAt.toIso8601String()}Z');
    }
    signer = OperationSignatureSigner.fromJson(json['signer']);
  }

  DateTime signedAt;

  OperationSignatureSigner signer;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OperationSignature &&
        runtimeType == other.runtimeType &&
        signedAt == other.signedAt &&
        signer == other.signer;
  }

  /// By default hashCode return reference
  @override
  int get hashCode => 0 ^ signedAt.hashCode ^ signer.hashCode;

  static List<OperationSignature> listFromJson(List<dynamic> json) {
    return json == null
        ? <OperationSignature>[]
        : json.map((value) => OperationSignature.fromJson(value)).toList();
  }

  static Map<String, OperationSignature> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationSignature>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationSignature.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'signedAt': signedAt == null ? '' : signedAt.toUtc().toIso8601String(),
      'signer': signer,
    };
  }

  @override
  String toString() {
    return 'OperationSignature[signedAt=$signedAt, signer=$signer, ]';
  }
}
